@@ -217,14 +217,16 @@ class Var:
 
 class Var2d(Var):
 
-    def __init__(self,var2d,fnam='',unit='',desc='',levl='',field=[]):
+    def __init__(self,var2d,fnam='',unit='',desc='',levl='',field=None):
 
         Var.__init__(self,fnam,unit,desc,levl,field)
         self.var2d = var2d
 
     def set_atr(self):
 
+    
         ffield = self.var2d.field
+        ffield = ffield.copy()
         ffield[~np.isfinite(ffield)]= np.nan
 
         try:
@@ -257,7 +259,7 @@ class Var2d(Var):
 
 class Var3d(Var):
 
-    def __init__(self,var3d,fnam='',unit='',desc='',levl=[],field=[]):
+    def __init__(self,var3d,fnam='',unit='',desc='',levl=[],field=None):
 
         Var.__init__(self,fnam,unit,desc,levl,field)
         self.var3d = var3d
@@ -265,6 +267,7 @@ class Var3d(Var):
     def set_atr(self):
 
         ffield = self.var3d.field
+        ffield = ffield.copy()
         ffield[~np.isfinite(ffield)]= np.nan
 
         try:
@@ -289,7 +292,7 @@ class Var3d(Var):
 
 class Var3dp(Var):
 
-    def __init__(self,var3dp,fnam='',unit='',desc='',levl=[],field=[]):
+    def __init__(self,var3dp,fnam='',unit='',desc='',levl=None,field=None):
 
         Var.__init__(self,fnam,unit,desc,levl,field)
         self.var3dp = var3dp
@@ -298,6 +301,7 @@ class Var3dp(Var):
     def set_atr(self):
 
         ffield = self.var3dp.field
+        ffield = ffield.copy()
         ffield[~np.isfinite(ffield)]= np.nan
 
         try:
@@ -318,7 +322,7 @@ class Var3dp(Var):
 
 class Varsl(Var):
 
-    def __init__(self,varsl,fnam='',unit='',desc='',levl='',slev=[],field=[]):
+    def __init__(self,varsl,fnam='',unit='',desc='',levl='',slev=[],field=None):
 
         Var.__init__(self,fnam,unit,desc,levl,field)
         self.varsl = varsl
@@ -327,6 +331,7 @@ class Varsl(Var):
     def set_atr(self):
 
         ffield = self.varsl.field
+        ffield = ffield.copy()
         ffield[~np.isfinite(ffield)]= np.nan
 
         try:
@@ -360,6 +365,7 @@ class V2d(Vuser):
         self.lev = lev
 
         self.verifdim()
+        #a,b,c = self.idvar()
 
     def verifdim(self):
          
@@ -438,6 +444,9 @@ class V2d(Vuser):
             uni = 'K'
             lev = '200100'
 
+        else:
+            raise Error('<'+self.name+'>'+' is not available for V2d. You can create a new field by this way V2d(nom,field,desc,units,level). please check the documentation')
+
         return nom,uni,lev
 
             
@@ -448,6 +457,7 @@ class V3d(Vuser):
         self.field = field
 
         self.verifdim()
+        a,b = self.idvar()
 
     def verifdim(self):
          
@@ -484,6 +494,9 @@ class V3d(Vuser):
             nom = '3-d pressure '
             uni = 'Pa'
 
+        else:
+            raise Error('<'+self.name+'>'+' is not valid V3d variable name')
+
         return nom,uni
 
 
@@ -495,6 +508,7 @@ class V3dp(Vuser):
         self.plevs = plevs
 
         self.verifdim()
+        a,b = self.idvar()
 
     def verifdim(self):
          
@@ -503,7 +517,7 @@ class V3dp(Vuser):
 
         if self.plevs.shape[0] != self.field.shape[0]:
             raise Error('number of pressure levels must match with 3D field')
-            
+
 
     def idvar(self):
         
@@ -531,6 +545,10 @@ class V3dp(Vuser):
             nom = '3-d geopotential height '
             uni = 'm'
 
+        else:
+            raise Error('<'+self.name+'>'+' is not valid V3dp variable name')
+
+
         return nom,uni
 
 
@@ -543,6 +561,7 @@ class Vsl(Vuser):
 
         self.verifdim()
         self.veriflevs()
+        a,b,c = self.idvar()
 
 
     def verifdim(self):
@@ -601,6 +620,10 @@ class Vsl(Vuser):
             uni = 'K'
             lev = '200100'
 
+        else:
+            raise Error('<'+self.name+'>'+' is not valid Vsl variable name')
+
+
         return nom,uni,lev
 
 
@@ -1013,7 +1036,6 @@ def cinter(filen,date,geoinfo,varias,rout=''):
 
             varia2d = Var2d(varia)
             varia2d.set_atr()
-
             variasf.append(varia2d)
 
 
